package SAE.ApiREST.WebService.controller;

import SAE.ApiREST.WebService.exception.ArticleException;
import SAE.ApiREST.WebService.exception.CollectException;
import SAE.ApiREST.WebService.model.Article;
import SAE.ApiREST.WebService.model.Collect;
import SAE.ApiREST.WebService.service.ICollectionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Controller
@RequestMapping("/CollectWebService")
public class CollectController {
    @Autowired
    ICollectionService collectionService;

    public CollectController() {

    }

    // region Collection

    // region GET
    @GetMapping(value = "/getAllCollection", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody List<Collect> getAllCollection(){
        List<Collect> results = collectionService.getAllCollections();
        if(results.isEmpty()) {
            throw new CollectException("No collections available");
        }
        return results;
    }
    @GetMapping(value = "/getCollectionById/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody Collect getCollectionById(@PathVariable(value = "id") Integer id){
        Collect results = collectionService.getCollectionById(id);
        if(results == null) {
            throw new CollectException("No collections available");
        }
        return results;
    }
    @GetMapping(value = "/getAllCollectionsByName/{name}", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody List<Collect> getAllCollectionsByName(@PathVariable(value = "name") String name){
        List<Collect> results = collectionService.getAllCollectionsByName(name);
        if(results.isEmpty()) {
            throw new CollectException("No collections available");
        }
        return results;
    }
    // endregion

    // region DELETE
    @DeleteMapping(value = "/deleteColletionById/{id}")
    public @ResponseBody void deleteColletionById(@RequestParam("id") Integer id){
        collectionService.deleteColletionById(id);
    }

    @DeleteMapping(value = "/deleteColletionByName/{name}")
    public @ResponseBody void deleteColletionByName(@RequestParam("name") String name){
        collectionService.deleteColletionByName(name);
    }

    @DeleteMapping(value = "/deleteAllColletionByName/{name}")
    public @ResponseBody void deleteAllColletionByName(@RequestParam("name") String name){
        collectionService.deleteAllColletionByName(name);
    }
    // endregion

    // region PUT
    @PutMapping(value = "/addCollection")
    public @ResponseBody void addCollection(@RequestParam("collection") Collect collection){
        collectionService.addCollection(collection);
    }

    @PutMapping(value = "/addCollections")
    public @ResponseBody void addCollections(@RequestParam("collections") List<Collect> collections){
        collectionService.addCollections(collections);
    }
    // endregion

    // region POST
    @PostMapping(value="/modifyCollectionName", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody void modifyCollectionName(@RequestParam("collection") Collect collection, @RequestParam("name") String name){
        collectionService.modifyCollectionName(collection,name);
    }

    @PostMapping(value="/modifyCollectionNameById/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody void modifyCollectionNameById(@RequestParam("id") Integer id, @RequestParam("name") String name){
        collectionService.modifyCollectionNameById(id,name);
    }
    // endregion
    // endregion

    // region Article
    @GetMapping(value = "/getAllArticlesById/{id}", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody List<Article> getAllArticlesById(@PathVariable(value = "id") Integer id){
        List<Article> results = collectionService.getAllArticlesById(id);
        if(results == null) {
            throw new ArticleException("No articles available");
        }

        return results;
    }

    @PutMapping(value = "/addArticle", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody void addArticle(@RequestParam("collection") Collect collection, @RequestParam("article") Article article){
        collectionService.addArticle(collection,article);
    }

    @DeleteMapping(value = "/deleteArticle", produces = MediaType.APPLICATION_JSON_VALUE)
    public @ResponseBody void deleteArticle(@RequestParam("collection") Collect collection, @RequestParam("article") Article article){
        collectionService.deleteArticle(collection,article);
    }
    //  endregion
}
